size_adapter library

Classes

SizeAdapter
Wrap your route level widget with SizeAdapter
SizeAdapterConfig

Extensions

SizeAdapterExt on num

Functions

adaptiveTextSize(double value) double
A method that returns the adaptive text size according to different screen sizes
calculateSafeScreenHeight(BuildContext context) double
Calculates the safe screen height by considering the device's screen height while accounting for factors such as the status bar, system overlays, and padding.
calculateSafeScreenWidth(BuildContext context) double
Calculates the safe screen width by considering the device's screen width while accounting for factors such as the left & right padding.
height(double inputHeight) double
-- screenHeight is the height of the screen the app is run on desginHeight is the design screen height
paddingHorizontal(double inputPadding) double
-- screenWidth is the width of the screen the app is run on desginWidth is the design screen width
paddingvertical(double inputPadding) double
-- screenHeight is the height of the screen the app is run on desginHeight is the design screen height
radius(double inputRadius) double
-- screenWidth is the width of the screen the app is run on desginWidth is the design screen width
width(double inputWidth) double
-- screenWidth is the width of the screen the app is run on desginWidth is the design screen width